diff --git a/exercises/euca.sh b/exercises/euca.sh
index 67150e4422..d0ca6c18fa 100755
--- a/exercises/euca.sh
+++ b/exercises/euca.sh
@@ -30,7 +30,8 @@ SECGROUP=euca_secgroup
 euca-add-group -d description $SECGROUP
 
 # Launch it
-INSTANCE=`euca-run-instances -g $SECGROUP -t m1.tiny $IMAGE | grep INSTANCE | cut -f2`
+DEFAULT_INSTANCE_TYPE=${DEFAULT_INSTANCE_TYPE:-m1.tiny}
+INSTANCE=`euca-run-instances -g $SECGROUP -t $DEFAULT_INSTANCE_TYPE $IMAGE | grep INSTANCE | cut -f2`
 
 # Assure it has booted within a reasonable time
 if ! timeout $RUNNING_TIMEOUT sh -c "while euca-describe-instances $INSTANCE | grep -q running; do sleep 1; done"; then
diff --git a/exercises/volumes.sh b/exercises/volumes.sh
index fe06b6edd6..6ea9a51685 100755
--- a/exercises/volumes.sh
+++ b/exercises/volumes.sh
@@ -52,10 +52,10 @@ IMAGE=`glance -A $TOKEN index | egrep ami | head -1 | cut -d" " -f1`
 # List of instance types:
 nova flavor-list
 
-INSTANCE_NAME=${DEFAULT_INSTANCE_TYPE:-m1.tiny}
-INSTANCE_TYPE=`nova flavor-list | grep $INSTANCE_NAME | cut -d"|" -f2`
-if [[ -z "`nova flavor-list | grep $INSTANCE_NAME | cut -d"|" -f2`" ]]; then
-    # and grab the first flavor in the list to launch
+DEFAULT_INSTANCE_TYPE=${DEFAULT_INSTANCE_TYPE:-m1.tiny}
+INSTANCE_TYPE=`nova flavor-list | grep $DEFAULT_INSTANCE_TYPE | cut -d"|" -f2`
+if [[ -z "$INSTANCE_TYPE" ]]; then
+    # grab the first flavor in the list to launch if default doesn't exist
    INSTANCE_TYPE=`nova flavor-list | head -n 4 | tail -n 1 | cut -d"|" -f2`
 fi
diff --git a/exercises/floating_ips.sh b/exercises/floating_ips.sh
index dca6d5be50..135c8c1c34 100755
--- a/exercises/floating_ips.sh
+++ b/exercises/floating_ips.sh
@@ -67,12 +67,16 @@ nova secgroup-create $SECGROUP "test_secgroup description"
 # List of flavors:
 nova flavor-list
 
-# and grab the first flavor in the list to launch
-FLAVOR=`nova flavor-list | head -n 4 | tail -n 1 | cut -d"|" -f2`
+DEFAULT_INSTANCE_TYPE=${DEFAULT_INSTANCE_TYPE:-m1.tiny}
+INSTANCE_TYPE=`nova flavor-list | grep $DEFAULT_INSTANCE_TYPE | cut -d"|" -f2`
+if [[ -z "$INSTANCE_TYPE" ]]; then
+    # grab the first flavor in the list to launch if default doesn't exist
+   INSTANCE_TYPE=`nova flavor-list | head -n 4 | tail -n 1 | cut -d"|" -f2`
+fi
 
 NAME="myserver"
 
-nova boot --flavor $FLAVOR --image $IMAGE $NAME --security_groups=$SECGROUP
+nova boot --flavor $INSTANCE_TYPE --image $IMAGE $NAME --security_groups=$SECGROUP
 
 # Testing
 # =======